<?php
/**
 * @author Harry Klein, http://www.joomla-hklein.de
 * @email harry.klein@hklein-joomla.de
 * @author Guillermo Vargas, http://joomla.vargas.co.cr
 * @email guille@vargas.co.cr
 * @version $Id: com_linkdirectory2.php,v 1.2 2010-04-22 21:52:41 harry Exp $
 * @package Xmap
 * @license GNU/GPL
 * @description Xmap plugin for H2N Link Directory component
 */

defined( '_JEXEC' ) or die( 'Restricted access.' );

class xmap_com_linkdirectory2 {
	
	const USE_LD2='useLd2';
	
	public function getTree( &$xmap, &$parent, &$params) {
		if ( strpos($parent->link, 'task=view.download') ) {
			return $list;
		}

		$link_query = parse_url( $parent->link );
		parse_str( html_entity_decode($link_query['query']), $link_vars );
		$catid = JArrayHelper::getValue($link_vars,'catid',0);

		$include_files = JArrayHelper::getValue( $params, 'include_files',1,'' );
		$include_files = ( $include_files == 1
		|| ( $include_files == 2 && $xmap->view == 'xml')
		|| ( $include_files == 3 && $xmap->view == 'html'));
		$params['include_files'] = $include_files;

		$priority = JArrayHelper::getValue($params,'cat_priority',$parent->priority,'');
		$changefreq = JArrayHelper::getValue($params,'cat_changefreq',$parent->changefreq,'');
		if ($priority  == '-1') {
			$priority = $parent->priority;
		}
		if ($changefreq  == '-1') {
			$changefreq = $parent->changefreq;
		}

		$params['cat_priority'] = $priority;
		$params['cat_changefreq'] = $changefreq;

		$priority = JArrayHelper::getValue($params,'file_priority',$parent->priority,'');
		$changefreq = JArrayHelper::getValue($params,'file_changefreq',$parent->changefreq,'');
		if ($priority  == '-1') {
			$priority = $parent->priority;
		}

		if ($changefreq  == '-1') {
			$changefreq = $parent->changefreq;
		}

		$params['file_priority'] = $priority;
		$params['file_changefreq'] = $changefreq;

		if ( $include_files ) {
			$limit = JArrayHelper::getValue($params,'max_files','','');
			if ( intval($limit) ) {
				$params['limit'] = ' LIMIT '.$limit;
			} else {
				$params['limit'] = '';
			} 
			$days = JArrayHelper::getValue($params,'max_age','','');
			if ( intval($days) ) {
				$params['max_art_age'] = ' AND created >= \''.date('Y-m-d H:m:s', ($xmap->now - ($days*86400)) ) ."' ";
			} else {
				$params['max_art_age'] = '';
			}
		}
		$params[self::USE_LD2] = self::isLd2($link_query['query']);
		self::getLinkDirectoryTree( $xmap, $parent, $params, $catid );
	}
	

	private function getLinkDirectoryTree ( &$xmap, &$parent, &$params, &$catid ) {
		$db = JFactory::getDBO();
		$db->setQuery("select id, name, parent_id from #__ldcats where parent_id=$catid and published = '1' order by title");
		$cats = $db->loadObjectList();
		$xmap->changeLevel(1);
		foreach($cats as $cat) {
			$node = new stdclass;
			$node->id   = $parent->id;
			$node->uid  = $parent->uid.'c'.$cat->id;   // Uniq ID for the category
			$node->pid  = $cat->parent_id;
			$node->name = $cat->name;
			$node->priority   = $params['cat_priority'];
			$node->changefreq = $params['cat_changefreq'];
			$node->expandible=true;
			$node->link = self::getCategoryUrl($cat->id, $params[self::USE_LD2]);
			$node->tree = array();

			if ($xmap->printNode($node) !== FALSE ) {
				self::getLinkDirectoryTree($xmap, $parent, $params, $cat->id);
			}

			if ( $params['include_files'] ) {
				$db->setQuery ('select id, title, catid from #__ldlinks where catid = '. $cat->id . ' and published = \'1\' ' .  $params['max_art_age']. ' order by title '. $params['limit']);
				$links = $db->loadObjectList();
				$xmap->changeLevel(1);
				foreach($links as $link) {
					$node = new stdclass;
					$node->id   = $parent->id; 
					$node->uid  = $parent->uid .'d'.$link->id;
					$node->name = $link->title;
					$node->link = self::getLinkUrl($link->id, $params[self::USE_LD2]);
					$node->priority   = $params['file_priority'];
					$node->changefreq = $params['file_changefreq'];
					$node->expandible=false;
					$node->tree = array();
					$xmap->printNode($node);
				}
				$xmap->changeLevel(-1);
			}
		}
		$xmap->changeLevel(-1);
	}
	
	/**
	 * Build Url to Weblink Detail Page
	 * @param int $id Weblink id
	 * @param boolean $useLd2 Links in H2N Link Directory 2 Style
	 * @return Url to Weblink Detail Page 
	 * 
	 */
	private function getLinkUrl($id, $useLd2){
		if ($useLd2){
			$option='com_linkdirectory2&view=link';
			$task = NULL;	
		} else {
			$option='com_linkdirectory';
			$task = 'detail';
		}	
		$url='index.php?option='.$option;
		if ($task) $url.='&task='.$task;
		if ($id) $url.='&id='.$id;
		return JRoute::_($url);
	}
	
	private function isLd2($option){
		switch ($option){
			case 'option=com_linkdirectory':
				return false;
				break;
			case 'option=com_linkdirectory2':
			default:
				return true;
				break;
		}
	}
	
	/**
	 * Build URL to Webcategory
	 * @param int $catid
	 * @param boolean $useLd2 Links in H2N Link Directory 2 Style
	 * @return URL to Webcategory
	 */
	private function getCategoryUrl($catid, $useLd2){
		if ($useLd2){
			$option='com_linkdirectory2&view=categories';
			$task = NULL;	
		} else {
			$option='com_linkdirectory';
			if ($catid != 0){
				$task = 'viewcat';
			} else {
				$task = NULL;
			}
		}	
		$url='index.php?option='.$option;
		if ($task) $url.='&task='.$task;
		if ($catid) $url.='&catid='.$catid;
		return JRoute::_($url);
	} 
}
